@@ -112,6 +112,9 @@ class ImageClass:
         pylab.imshow(self.get_voxel_grid()[img_slice, :, :], cmap=pylab.cm.bone)
         pylab.show()
 
+    def set_origin(self, new_origin):
+        self.origin = new_origin
+
     def set_spacing(self, new_spacing):
 
         # Update spacing
@@ -564,7 +567,7 @@ class ImageClass:
             return
 
         import scipy.ndimage as ndi
-        from src.radiology.mirp.featureSets.volumeMorphology import get_rotation_matrix
+        from luna.radiology.mirp.featureSets.volumeMorphology import get_rotation_matrix
 
         # Find actual output size of x-y plane
         new_z_dim = np.asmatrix([self.size[0], 0.0, 0.0]) * get_rotation_matrix(np.radians(angle), dim=3, rot_axis=0)
@@ -595,7 +598,7 @@ class ImageClass:
     def crop(self, ind_ext_z=None, ind_ext_y=None, ind_ext_x=None,
              xy_only=False, z_only=False):
         """"Crop image to the provided map extent."""
-        from src.radiology.mirp.utilities import world_to_index
+        from luna.radiology.mirp.utilities import world_to_index
 
         # Skip for missing images
         if self.is_missing:
